searchData={"items":[{"type":"module","title":"OffBroadway.Telegram.Producer","doc":"A GenStage producer that continuously polls messages from a Telegram Bot API `getUpdates` endpoint","ref":"OffBroadway.Telegram.Producer.html"},{"type":"module","title":"Options - OffBroadway.Telegram.Producer","doc":"The following options are supported:\n\n  * `receive_interval` - for how long (in milliseconds) a producer will wait before checking for updates. Default: 1000\n  * `client` - a module-options tuple that implements `OffBroadway.Telegram.TelegramClient` behaviour. Default: `{OffBroadway.Telegram.ReqClient, []}`","ref":"OffBroadway.Telegram.Producer.html#module-options"},{"type":"module","title":"OffBroadway.Telegram.ReqClient","doc":"`TelegramClient` implementation using `Req`.","ref":"OffBroadway.Telegram.ReqClient.html"},{"type":"function","title":"OffBroadway.Telegram.ReqClient.to_broadway_message/1","doc":"","ref":"OffBroadway.Telegram.ReqClient.html#to_broadway_message/1"},{"type":"behaviour","title":"OffBroadway.Telegram.TelegramClient","doc":"A generic behavior to implement Telegram Client for `OffBroadway.Telegram.Producer`.\nThis module defines callbacks to fetch updates from Telegram Bot API via long polling","ref":"OffBroadway.Telegram.TelegramClient.html"},{"type":"callback","title":"OffBroadway.Telegram.TelegramClient.get_updates/3","doc":"","ref":"OffBroadway.Telegram.TelegramClient.html#c:get_updates/3"},{"type":"extras","title":"OffBroadway.Telegram","doc":"# OffBroadway.Telegram\n\nAn Off-[Broadway](https://github.com/dashbitco/broadway) producer for [Telegram Bot API long polling](https://core.telegram.org/bots)\n\nThis package provides:\n\n  * `OffBroadway.Telegram.Producer` - Broadway producer that polls updates from Telegram `getUpdates` long polling endpoint and feeds them through Broadway pipeline\n  * `OffBroadway.Telegram.TelegramClient` - A generic behaviour to implement Telegram client\n  * `OffBroadway.Telegram.ReqClient` - Telegram client based on `Req` package","ref":"readme.html"},{"type":"extras","title":"Why - OffBroadway.Telegram","doc":"Telegram bots have two ways of getting updates: long polling or web hook. While setting up a web hook is preferable way for production it is very common to use long polling in development environment or for smaller bots. Setting up a worker for long polling is not hard but consists mostly of [boilerplate code](https://github.com/lubien/elixir-telegram-bot-boilerplate/blob/master/lib/app/poller.ex).\n\nBut hey, we can use Broadway for this!","ref":"readme.html#why"},{"type":"extras","title":"Installation - OffBroadway.Telegram","doc":"Add `off_broadway_telegram` and `Req` to your list of dependencies in `mix.exs` :\n\n```elixir\ndef deps do\n  [\n    {:off_broadway_telegram, \"~> 0.1.0\"},\n    {:req, \"~> 0.5.7\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Example - OffBroadway.Telegram","doc":"All you need to do is define a pipeline like this:\n\n```elixir\ndefmodule BroadwayTelegramExample do\n  use Broadway\n\n  def start_link(bot_token) do\n    Broadway.start_link(__MODULE__,\n      name: __MODULE__,\n      producer: [\n        module:\n          {OffBroadway.Telegram.Producer,\n           [client: {OffBroadway.Telegram.ReqClient, [token: bot_token]}]},\n        concurrency: 1\n      ],\n      processors: [\n        default: [concurrency: 2]\n      ]\n    )\n  end\n\n  @impl Broadway\n  def handle_message(\n        _processor,\n        %Broadway.Message{\n          data: update\n        } = message,\n        _context\n      ) do\n    MyApp.process_update(update)\n\n    message\n  end\nend\n```\n\nand add it to your application's supervisor tree in `application.ex`:\n\n```\nchildren = [\n  {BroadwayTelegramExample, [Application.fetch_env!(:myapp, :bot_token)]]}\n]\n\nSupervisor.start_link(children, strategy: :one_for_one)\n```\n\nEverything else is up to your creativity!","ref":"readme.html#example"},{"type":"extras","title":"Caveats - OffBroadway.Telegram","doc":"Worth noting that **Telegram `getUpdates` is not a proper pubsub** like Google PubSub or SQS! This means:\n\n  1. you don't want to run more than one producer process per bot\n  2. there is no ack/nack and therefore no built-in retry mechanism","ref":"readme.html#caveats"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,50]},"content_type":"text/markdown"}